==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_functions/mp0071_001/MP0071_AddWorkOrderPart_001.java <==

package net.datastream.schemas.mp_functions.mp0071_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.workorderpart_001.WorkOrderPart;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_entities/WorkOrderPart_001}WorkOrderPart"/>
 *       </sequence>
 *       <attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Add" />
 *       <attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="WorkOrderPart" />
 *       <attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       <attribute name="callname" type="{http://www.w3.org/2001/XMLSchema}string" default="AddWorkOrderPart" />
 *       <attribute name="confirm_add_part" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       <attribute name="is_newpart" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workOrderPart"
})
@XmlRootElement(name = "MP0071_AddWorkOrderPart_001")
public class MP0071_AddWorkOrderPart_001 {

    @XmlElement(name = "WorkOrderPart", namespace = "http://schemas.datastream.net/MP_entities/WorkOrderPart_001", required = true)
    protected WorkOrderPart workOrderPart;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "callname")
    protected String callname;
    @XmlAttribute(name = "confirm_add_part")
    protected String confirm_Add_Part;
    @XmlAttribute(name = "is_newpart")
    protected String is_Newpart;

    /**
     * Gets the value of the workOrderPart property.
     * 
     * @return
     *     possible object is
     *     {@link WorkOrderPart }
     *     
     */
    public WorkOrderPart getWorkOrderPart() {
        return workOrderPart;
    }

    /**
     * Sets the value of the workOrderPart property.
     * 
     * @param value
     *     allowed object is
     *     {@link WorkOrderPart }
     *     
     */
    public void setWorkOrderPart(WorkOrderPart value) {
        this.workOrderPart = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.ADD;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.WORK_ORDER_PART;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the callname property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCallname() {
        if (callname == null) {
            return "AddWorkOrderPart";
        } else {
            return callname;
        }
    }

    /**
     * Sets the value of the callname property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCallname(String value) {
        this.callname = value;
    }

    /**
     * Gets the value of the confirm_Add_Part property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Add_Part() {
        if (confirm_Add_Part == null) {
            return "prompt";
        } else {
            return confirm_Add_Part;
        }
    }

    /**
     * Sets the value of the confirm_Add_Part property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Add_Part(String value) {
        this.confirm_Add_Part = value;
    }

    /**
     * Gets the value of the is_Newpart property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIs_Newpart() {
        if (is_Newpart == null) {
            return "false";
        } else {
            return is_Newpart;
        }
    }

    /**
     * Sets the value of the is_Newpart property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIs_Newpart(String value) {
        this.is_Newpart = value;
    }

}

==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_functions/mp0071_001/MP0071_AddWorkOrderPart_001.java <==

package net.datastream.schemas.mp_functions.mp0071_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.workorderpart_001.WorkOrderPart;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkOrderPart_001}WorkOrderPart"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Add" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="WorkOrderPart" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="callname" type="{http://www.w3.org/2001/XMLSchema}string" default="AddWorkOrderPart" />
 *       &lt;attribute name="confirm_add_part" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *       &lt;attribute name="is_newpart" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "workOrderPart"
})
@XmlRootElement(name = "MP0071_AddWorkOrderPart_001")
public class MP0071_AddWorkOrderPart_001 {

    @XmlElement(name = "WorkOrderPart", namespace = "http://schemas.datastream.net/MP_entities/WorkOrderPart_001", required = true)
    protected WorkOrderPart workOrderPart;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "callname")
    protected String callname;
    @XmlAttribute(name = "confirm_add_part")
    protected String confirm_Add_Part;
    @XmlAttribute(name = "is_newpart")
    protected String is_Newpart;

    /**
     * Gets the value of the workOrderPart property.
     * 
     * @return
     *     possible object is
     *     {@link WorkOrderPart }
     *     
     */
    public WorkOrderPart getWorkOrderPart() {
        return workOrderPart;
    }

    /**
     * Sets the value of the workOrderPart property.
     * 
     * @param value
     *     allowed object is
     *     {@link WorkOrderPart }
     *     
     */
    public void setWorkOrderPart(WorkOrderPart value) {
        this.workOrderPart = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.ADD;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.WORK_ORDER_PART;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the callname property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCallname() {
        if (callname == null) {
            return "AddWorkOrderPart";
        } else {
            return callname;
        }
    }

    /**
     * Sets the value of the callname property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCallname(String value) {
        this.callname = value;
    }

    /**
     * Gets the value of the confirm_Add_Part property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Add_Part() {
        if (confirm_Add_Part == null) {
            return "prompt";
        } else {
            return confirm_Add_Part;
        }
    }

    /**
     * Sets the value of the confirm_Add_Part property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Add_Part(String value) {
        this.confirm_Add_Part = value;
    }

    /**
     * Gets the value of the is_Newpart property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIs_Newpart() {
        if (is_Newpart == null) {
            return "false";
        } else {
            return is_Newpart;
        }
    }

    /**
     * Sets the value of the is_Newpart property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIs_Newpart(String value) {
        this.is_Newpart = value;
    }

}
